/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WorkerAction.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.action;

import java.lang.reflect.Constructor;
import java.util.Hashtable;
import java.util.Map;

import org.ow2.jasmine.jadort.service.entities.ModJKBean;
import org.ow2.jasmine.jadort.service.entities.ServerBean;

/**
 * Action for a worker (ModJK or other)
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
public abstract class WorkerAction extends AbstractAction {

    private static Constructor<? extends WorkerAction> constructor;
    private static Map<String, WorkerAction> pool = new Hashtable<String, WorkerAction>();

    public static WorkerAction getWorkerAction(final ModJKBean server) {
        synchronized (WorkerAction.pool) {
            String key = WorkerAction.getKey(server);
            WorkerAction workerAction = WorkerAction.pool.get(key);
            if (workerAction == null) {
                workerAction = WorkerAction.newInstance(server);
                WorkerAction.pool.put(key, workerAction);
            }
            return workerAction;
        }
    }

    private static String getKey(final ModJKBean server) {
        StringBuilder sb = new StringBuilder();
        sb.append(server.getName());
        sb.append(server.getConnector().getConnectorUrl());
        if (server.getConnector().getUsername() != null && server.getConnector().getPassword() != null) {
            sb.append(server.getConnector().getUsername());
            sb.append(server.getConnector().getPassword());
        }
        return sb.toString();
    }

    protected static WorkerAction newInstance(final ModJKBean server) {
        try {
            if (WorkerAction.constructor == null) {
                WorkerAction.getConstructor(DummyWorkerAction.class);
            }
            return WorkerAction.constructor.newInstance(server);
        } catch (Exception e) {
            throw new IllegalArgumentException("Failed creating the worker action", e);
        }
    }

    @SuppressWarnings("unchecked")
    protected static void getConstructor(final Class<? extends WorkerAction> actionType) throws Exception {
        Constructor[] constructors = actionType.getDeclaredConstructors();
        for (Constructor<? extends WorkerAction> constructor : constructors) {
            Class<?>[] params = constructor.getParameterTypes();
            if (params.length == 1 && params[0] == ModJKBean.class) {
                WorkerAction.constructor = constructor;
            }
        }
    }

    /**
     * @param actionType The action type to set, that'll be used in the
     *        {@link WorkerAction#getServerAction(ServerBean)} method.
     */
    public static void setActionType(final Class<? extends WorkerAction> actionType) {
        try {
            WorkerAction.getConstructor(actionType);
        } catch (Exception e) {
            throw new IllegalArgumentException("Failed setting ActionType", e);
        }
    }

}
