/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GroupBean.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.entities;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.OneToMany;

/**
 * Bean that represents a group of server (cluster or farm)
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
@Entity
public class GroupBean implements Serializable {

    /**
     * Use for serialization
     */
    private static final long serialVersionUID = -1783631991681445491L;

    /**
     * Group id, use for persistence
     */
    @Id
    @GeneratedValue
    @SuppressWarnings("unused")
    private Integer id;

    /**
     * Key word for farm servers group
     */
    public static String FARM = "Farm";

    /**
     * Key word for cluster servers group.
     */
    public static String CLUSTER = "Cluster";

    /**
     * List of modJKs for this group
     */
    @OneToMany(cascade = CascadeType.ALL)
    protected List<ModJKBean> modJK = new ArrayList<ModJKBean>();

    /**
     * Group name
     */
    protected String name;

    /**
     * Group type (Farm or Cluster)
     */
    protected String type;

    /**
     * List of servers for this group
     */
    @OneToMany(cascade = CascadeType.ALL)
    protected List<ServerBean> servers = new ArrayList<ServerBean>();

    /**
     * Application list deployed on the servers of this group
     */
    @OneToMany(cascade = CascadeType.ALL)
    protected List<ApplicationBean> applications = new ArrayList<ApplicationBean>();

    /**
     * Get the ModJKs list for this group
     * 
     * @return ModJKs list for this group
     */
    public List<ModJKBean> getModJK() {
        return this.modJK;
    }

    /**
     * Set the ModJKs list for this group
     * 
     * @param modJK ModJKs list for this group
     */
    public void setModJK(final List<ModJKBean> modJK) {
        this.modJK = modJK;
    }

    /**
     * Get the group name
     * 
     * @return The group name
     */
    public String getName() {
        return this.name;
    }

    /**
     * Set the group name
     * 
     * @param name New name for the group
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * Get the group type
     * 
     * @return The group type
     */
    public String getType() {
        return this.type;
    }

    /**
     * Set the group type
     * 
     * @param type New group type
     */
    public void setType(final String type) {
        this.type = type;
    }

    /**
     * Get the servers list for this group
     * 
     * @return The servers list for this group
     */
    public List<ServerBean> getServers() {
        return this.servers;
    }

    /**
     * Set the servers list for this group
     * 
     * @param servers The servers list to set for this group
     */
    public void setServers(final List<ServerBean> servers) {
        this.servers = servers;
    }

    /**
     * Get the applications list for this group
     * 
     * @return The applications list for this group
     */
    public List<ApplicationBean> getApplications() {
        return this.applications;
    }

    /**
     * Set the applications list for this group
     * 
     * @param applications The applications list to set for this group
     */
    public void setApplications(final List<ApplicationBean> applications) {
        this.applications = applications;
    }

    /**
     * Returns a string that displays and identifies this object's properties.
     * 
     * @return A string that displays and identifies this object's properties.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder(this.getClass().getSimpleName());
        sb.append("[name='");
        sb.append(name);
        sb.append("', type='");
        sb.append(type);
        sb.append("']");
        return sb.toString();
    }

    /**
     * Get the group id
     * 
     * @return Group id
     */
    public Integer getId() {
        return this.id;
    }

    public void setId(final Integer id) {
        this.id = id;
    }

}
