/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JMXConnectorBean.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.entities;

import java.io.Serializable;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;

/**
 * Bean that represents a JMX connector
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
@Entity
public class JMXConnectorBean implements Serializable {

    /**
     * Used for serialization
     */
    private static final long serialVersionUID = -8493966892797382963L;

    /**
     * JMXConector id, use for persistence
     */
    @Id
    @GeneratedValue
    @SuppressWarnings("unused")
    private Integer id;

    /**
     * URL of the JMX connector
     */
    private String connectorUrl;

    /**
     * JMX connector password
     */
    private String password;

    /**
     * JMX connector username
     */
    private String username;

    /**
     * Getter of the connector url
     * 
     * @return connector url
     */
    public String getConnectorUrl() {
        return this.connectorUrl;
    }

    /**
     * Setter of the connector url
     * 
     * @param connectorUrl connector url
     */
    public void setConnectorUrl(final String connectorUrl) {
        this.connectorUrl = connectorUrl;
    }

    /**
     * Getter of the password
     * 
     * @return the password
     */
    public String getPassword() {
        return this.password;
    }

    /**
     * Setter of the password
     * 
     * @param password the password
     */
    public void setPassword(final String password) {
        this.password = password;
    }

    /**
     * Getter of the username
     * 
     * @return the username
     */
    public String getUsername() {
        return this.username;
    }

    /**
     * Setter of the username
     * 
     * @param username the username
     */
    public void setUsername(final String username) {
        this.username = username;
    }

    /**
     * Returns a string that displays and identifies this object's properties.
     * 
     * @return A string that displays and identifies this object's properties.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder(this.getClass().getSimpleName());
        sb.append("[connectorUrl='");
        sb.append(connectorUrl);
        sb.append("']");
        return sb.toString();
    }

}
