/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ModJKBean.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.entities;

import java.io.Serializable;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.OneToOne;

/**
 * Bean that represents a ModJK worker
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
@Entity
public class ModJKBean implements Serializable {

    /**
     * Used for serialization
     */
    private static final long serialVersionUID = -2642244770533383105L;

    /**
     * ModJK id, use for persistence
     */
    @Id
    @GeneratedValue
    @SuppressWarnings("unused")
    private Integer id;

    /**
     * ModJK name
     */
    private String name;

    /**
     * ModJK onnnector
     */
    @OneToOne(cascade = CascadeType.ALL)
    private JMXConnectorBean connector;

    /**
     * Getter for name
     * 
     * @return modJK name
     */
    public String getName() {
        return this.name;
    }

    /**
     * Setter for name
     * 
     * @param name New modJK name
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * Getter for JMX connector
     * 
     * @return The associated JMX connector
     */
    public JMXConnectorBean getConnector() {
        return this.connector;
    }

    /**
     * Setter for JMX connector
     * 
     * @param connector JMX connector to set
     */
    public void setConnector(final JMXConnectorBean connector) {
        this.connector = connector;
    }

    /**
     * Returns a string that displays and identifies this object's properties.
     * 
     * @return A string that displays and identifies this object's properties.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder(this.getClass().getSimpleName());
        sb.append("[name='");
        sb.append(name);
        sb.append("', connector='");
        sb.append(connector);
        sb.append("']");
        return sb.toString();
    }

    /**
     * Getter for id
     * 
     * @return the modJK id
     */
    public Integer getId() {
        return this.id;
    }
}
