/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ServerBean.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.entities;

import java.io.Serializable;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.OneToOne;

/**
 * Bean represents a application server
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
@Entity
public class ServerBean implements Serializable {

    /**
     * For serialization
     */
    private static final long serialVersionUID = -8338670679543686581L;

    /**
     * Id of the server, use for persistence. Auto generated.
     */
    @Id
    @GeneratedValue
    @SuppressWarnings("unused")
    private Integer id;

    /**
     * Server name
     */
    private String name;

    /**
     * Server capacity
     */
    private Integer capacity;

    /**
     * Server JMX connnector
     */
    @OneToOne(cascade = CascadeType.ALL)
    private JMXConnectorBean connector;

    /**
     * Get the server name
     *
     * @return the server name
     */
    public String getName() {
        return this.name;
    }

    /**
     * Set the server name
     *
     * @param name the server name
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * Get the server capacity
     *
     * @return the server capacity
     */
    public Integer getCapacity() {
        return this.capacity;
    }

    /**
     * Set the server capacity
     *
     * @param capacity the server capacity
     */
    public void setCapacity(final Integer capacity) {
        this.capacity = capacity;
    }

    /**
     * Get the server JMX connector
     *
     * @return the server JMX connector
     */
    public JMXConnectorBean getConnector() {
        return this.connector;
    }

    /**
     * Set the server JMX connector
     *
     * @param connector the server JMX connector
     */
    public void setConnector(final JMXConnectorBean connector) {
        this.connector = connector;
    }

    /**
     * Returns a string that displays and identifies this object's properties.
     *
     * @return A string that displays and identifies this object's properties.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder(this.getClass().getSimpleName());
        sb.append("[name='");
        sb.append(name);
        sb.append("', capacity='");
        sb.append(capacity);
        sb.append("', connector='");
        sb.append(connector);
        sb.append("']");
        return sb.toString();
    }

    /**
     * Get the server id
     *
     * @return the server id
     */
    public Integer getId() {
        return this.id;
    }

    /**
     * Set the server id
     *
     * @param id the server id
     */
    public void setId(final Integer id) {
        this.id = id;
    }

}
