/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TopologyBean.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.entities;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.OneToMany;

/**
 * Bean that represents a topoogy of servers
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
@Entity
public class TopologyBean implements Serializable {

    /**
     * For serialization
     */
    private static final long serialVersionUID = 7176306212817449305L;

    /**
     * Topology id, use for persistence. Auto generated.
     */
    @Id
    @GeneratedValue
    @SuppressWarnings("unused")
    private Integer id;

    /**
     * Servers groups that compose the toplogy
     */
    @OneToMany(cascade = CascadeType.ALL)
    private List<GroupBean> groups;

    /**
     * Get the groups
     * 
     * @return the groups
     */
    public List<GroupBean> getGroups() {
        if (groups != null) {
            return new ArrayList<GroupBean>(groups);
        } else {
            return null;
        }
    }

    /**
     * Set the groups
     * 
     * @param groups The groups list to set
     */
    public void setGroups(final List<GroupBean> groups) {
        this.groups = groups;
    }

    /**
     * Get the id
     * 
     * @return The id
     */
    public Integer getId() {
        return this.id;
    }

    public void setId(final Integer id) {
        this.id = id;
    }

}
