/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ApplicationBeanTest.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.entities;

import java.io.File;
import java.io.FileNotFoundException;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.util.archive.api.ArchiveException;
import org.ow2.util.ee.deploy.impl.helper.DeployableHelperException;

/**
 * Tests the ApplicationBean class.
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
public class ApplicationBeanTest {

    /**
     * @throws java.lang.Exception
     */
    @BeforeClass
    public static void setUpBeforeClass() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @AfterClass
    public static void tearDownAfterClass() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @Before
    public void setUp() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @After
    public void tearDown() throws Exception {
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#ApplicationBean()}.
     */
    @Test
    public void testApplicationBean() {
        ApplicationBean appli = null;
        appli = new ApplicationBean();
        Assert.assertNotNull("Test empty constructor", appli);
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#ApplicationBean(java.io.File)}.
     */
    @Test
    public void testApplicationBeanFile() {

        /* First test with a good archive */
        File file = new File("../../../../../../../../application1.ear");
        ApplicationBean appli = null;
        try {
            appli = new ApplicationBean(file);
        } catch (FileNotFoundException e) {
            Assert.fail("Test constructor with archive : " + e.getMessage());
        } catch (DeployableHelperException e) {
            Assert.fail("Test constructor with archive : " + e.getMessage());
        } catch (ArchiveException e) {
            Assert.fail("Test constructor with archive : " + e.getMessage());
        }
        Assert.assertNotNull(appli);
        Assert.assertSame(file, appli.getFile());

        /* Now test with a bad archive */
        appli = null;
        file = new File("../../../../../../../../noApplication.war");
        try {
            appli = new ApplicationBean(file);
        } catch (FileNotFoundException e) {
            Assert.fail("Test constructor with bad archive : " + e.getMessage());
        } catch (DeployableHelperException e) {
        } catch (ArchiveException e) {
        }

        Assert.assertNull(appli);
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#ApplicationBean(java.lang.String)}.
     */
    @Test
    public void testApplicationBeanString() {
        String name = "test";
        ApplicationBean appli = new ApplicationBean(name);
        Assert.assertNotNull(appli);
        Assert.assertEquals(appli.getName(), name);
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#ApplicationBean(java.lang.String, java.lang.String)}.
     */
    @Test
    public void testApplicationBeanStringString() {
        String name = "test";
        String version = "v1";
        ApplicationBean appli = new ApplicationBean(name, version);
        Assert.assertNotNull(appli);
        Assert.assertEquals(appli.getName(), name);
        Assert.assertEquals(appli.getVersion(), version);
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#getName()}.
     */
    @Test
    public void testGetSetName() {
        ApplicationBean application = new ApplicationBean();
        String name = "test";

        Assert.assertNull(application.getName());
        application.setName(name);
        Assert.assertNotNull(application.getName());
        Assert.assertEquals(name, application.getName());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#getVersion()}.
     */
    @Test
    public void testGetSetVersion() {
        ApplicationBean application = new ApplicationBean();
        String version = "test";

        Assert.assertNull(application.getVersion());
        application.setVersion(version);
        Assert.assertNotNull(application.getVersion());
        Assert.assertEquals(version, application.getVersion());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#getFile()}.
     */
    @Test
    public void testGetSetFile() {
        ApplicationBean application = new ApplicationBean();
        File file = new File("test");

        Assert.assertNull(application.getFile());
        application.setFile(file);
        Assert.assertNotNull(application.getFile());
        Assert.assertEquals(file, application.getFile());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#getPolicy()}.
     */
    @Test
    public void testGetSetPolicy() {
        ApplicationBean application = new ApplicationBean();
        String policy = new String("test");

        Assert.assertNull(application.getPolicy());
        application.setPolicy(policy);
        Assert.assertNotNull(application.getPolicy());
        Assert.assertEquals(policy, application.getPolicy());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#getState()}.
     */
    @Test
    public void testGetSetState() {
        ApplicationBean application = new ApplicationBean();
        String state = new String("test");

        Assert.assertNull(application.getState());
        application.setState(state);
        Assert.assertNotNull(application.getState());
        Assert.assertEquals(state, application.getState());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#toString()}.
     */
    @Test
    public void testToString() {
        ApplicationBean application = new ApplicationBean();
        Assert.assertNotNull(application.toString());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.ApplicationBean#getId()}.
     */

    @Test
    public void testGetId() {
        ApplicationBean application = new ApplicationBean();
        Assert.assertNull(application.getId());

    }
}
