/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DeploymentBeanTest.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.entities;

import java.util.UUID;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.jasmine.jadort.service.entities.DeploymentBean.ActionState;
import org.ow2.jasmine.jadort.service.entities.DeploymentBean.DeploymentState;

/**
 * Tests the DeploymentBean class.
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
public class DeploymentBeanTest {

    DeploymentBean deployment;

    /**
     * @throws java.lang.Exception
     */
    @BeforeClass
    public static void setUpBeforeClass() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @AfterClass
    public static void tearDownAfterClass() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @Before
    public void setUp() throws Exception {
        deployment = new DeploymentBean();
    }

    /**
     * @throws java.lang.Exception
     */
    @After
    public void tearDown() throws Exception {
        deployment = null;
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#DeploymentBean()}.
     */
    @Test
    public void testDeploymentBean() {
        Assert.assertNotNull(deployment);
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#DeploymentBean(org.ow2.jasmine.jadort.service.entities.ServerBean)}.
     */
    @Test
    public void testDeploymentBeanServerBean() {
        ServerBean s = new ServerBean();
        deployment = new DeploymentBean(s);

        Assert.assertNotNull(deployment);
        Assert.assertEquals(s, deployment.getServer());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#getServer()}.
     */
    @Test
    public void testGetSetServer() {
        ServerBean s = new ServerBean();
        deployment.setServer(s);
        Assert.assertEquals(s, deployment.getServer());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#getServerName()}.
     */
    @Test
    public void testGetSetServerName() {
        ServerBean s = new ServerBean();
        String name = UUID.randomUUID().toString();
        s.setName(name);
        deployment.setServer(s);

        Assert.assertEquals(name, deployment.getServerName());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#isSelected()}.
     */
    @Test
    public void testIsSetSelected() {
        deployment.setSelected(false);
        Assert.assertFalse(deployment.isSelected());

        deployment.setSelected(true);
        Assert.assertTrue(deployment.isSelected());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#getState()}.
     */
    @Test
    public void testGetSetState() {
        String state = UUID.randomUUID().toString();
        deployment.setState(state);

        /*
         * The method setState don't have to work!
         */
        Assert.assertFalse(state.equals(deployment.getState()));

        Assert.assertEquals("Waiting", deployment.getState());

        deployment.setActionState(ActionState.RUNNING);
        Assert.assertEquals("Running", deployment.getState());

        deployment.setActionState(ActionState.FINISHED_OK);
        Assert.assertEquals("Done OK", deployment.getState());

        deployment.setActionState(ActionState.FINISHED_ERROR);
        Assert.assertEquals("Error !", deployment.getState());

        deployment.setActionState(ActionState.WAITING);
        Assert.assertEquals("Waiting", deployment.getState());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#getOldApplication()}.
     */
    @Test
    public void testGetSetOldApplication() {
        String oldApplication = UUID.randomUUID().toString();
        deployment.setOldApplication(oldApplication);

        Assert.assertEquals(oldApplication, deployment.getOldApplication());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#getNewApplication()}.
     */
    @Test
    public void testGetSetNewApplication() {
        String newApplication = UUID.randomUUID().toString();
        deployment.setNewApplication(newApplication);

        Assert.assertEquals(newApplication, deployment.getNewApplication());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#getProgress()}.
     */
    @Test
    public void testGetSetProgress() {
        Integer progress = (int) (Math.random() * 100);

        deployment.setProgress(progress);
        Assert.assertEquals(progress, deployment.getProgress());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#getLog()}.
     */
    @Test
    public void testGetSetAppentLog() {
        StringBuilder log = new StringBuilder("titi"/* UUID.randomUUID().toString() */);

        deployment.setLog(log.toString());
        Assert.assertEquals(log.toString(), deployment.getLog());

        String log2 = "toto";// UUID.randomUUID().toString();
        deployment.appendToLog(log2);

        Assert.assertEquals(log.append('\n' + log2).toString(), deployment.getLog());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#getDeploymentState()}.
     */
    @Test
    public void testGetSetDeploymentState() {
        Assert.assertEquals(DeploymentState.INITIAL, deployment.getDeploymentState());

        deployment.setDeploymentState(DeploymentState.DEPLOY_OK);
        Assert.assertEquals(DeploymentState.DEPLOY_OK, deployment.getDeploymentState());

        deployment.setDeploymentState(DeploymentState.ERASE_OK);
        Assert.assertEquals(DeploymentState.ERASE_OK, deployment.getDeploymentState());

        deployment.setDeploymentState(DeploymentState.INITIAL);
        Assert.assertEquals(DeploymentState.INITIAL, deployment.getDeploymentState());

        deployment.setDeploymentState(DeploymentState.SET_DEFAULT_OK);
        Assert.assertEquals(DeploymentState.SET_DEFAULT_OK, deployment.getDeploymentState());

        deployment.setDeploymentState(DeploymentState.UNDEPLOY_OK);
        Assert.assertEquals(DeploymentState.UNDEPLOY_OK, deployment.getDeploymentState());

        deployment.setDeploymentState(DeploymentState.UPLOAD_OK);
        Assert.assertEquals(DeploymentState.UPLOAD_OK, deployment.getDeploymentState());

    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#getActionState()}.
     */
    @Test
    public void testGetSetActionState() {
        Assert.assertEquals(ActionState.WAITING, deployment.getActionState());

        deployment.setActionState(ActionState.FINISHED_ERROR);
        Assert.assertEquals(ActionState.FINISHED_ERROR, deployment.getActionState());

        deployment.setActionState(ActionState.FINISHED_OK);
        Assert.assertEquals(ActionState.FINISHED_OK, deployment.getActionState());

        deployment.setActionState(ActionState.RUNNING);
        Assert.assertEquals(ActionState.RUNNING, deployment.getActionState());

        deployment.setActionState(ActionState.WAITING);
        Assert.assertEquals(ActionState.WAITING, deployment.getActionState());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#toString()}.
     */
    @Test
    public void testToString() {
        Assert.assertNotNull(deployment.toString());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.DeploymentBean#getId()}.
     */
    @Test
    public void testGetId() {
        Assert.assertNull(deployment.getId());
    }

}
