/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GroupBeanTest.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.entities;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Tests the GroupBean class.
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
public class GroupBeanTest {

    private GroupBean group;

    /**
     * @throws java.lang.Exception
     */
    @BeforeClass
    public static void setUpBeforeClass() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @AfterClass
    public static void tearDownAfterClass() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @Before
    public void setUp() throws Exception {
        group = new GroupBean();
    }

    /**
     * @throws java.lang.Exception
     */
    @After
    public void tearDown() throws Exception {
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#getModJK()}.
     */
    @Test
    public void testGetModJK() {
        Assert.assertNotNull(group.getModJK());
        Assert.assertEquals(group.getModJK().size(), 0);

        ArrayList<ModJKBean> modjks = new ArrayList<ModJKBean>();

        group.modJK = modjks;
        Assert.assertSame(modjks, group.getModJK());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#setModJK(java.util.List)}.
     */
    @Test
    public void testSetModJK() {
        ArrayList<ModJKBean> modjks = new ArrayList<ModJKBean>();
        group.setModJK(modjks);

        Assert.assertSame(modjks, group.modJK);
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#getName()}.
     */
    @Test
    public void testGetName() {
        Assert.assertNull(group.getName());

        String name = UUID.randomUUID().toString();

        group.name = name;
        Assert.assertSame(name, group.getName());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#setName(java.lang.String)}.
     */
    @Test
    public void testSetName() {
        String name = UUID.randomUUID().toString();
        group.setName(name);

        Assert.assertSame(name, group.name);
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#getType()}.
     */
    @Test
    public void testGetType() {
        Assert.assertNull(group.getType());

        String type = UUID.randomUUID().toString();

        group.type = type;
        Assert.assertSame(type, group.getType());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#setType(java.lang.String)}.
     */
    @Test
    public void testSetType() {
        String type = UUID.randomUUID().toString();
        group.setType(type);

        Assert.assertSame(type, group.type);
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#getServers()}.
     */
    @Test
    public void testGetServers() {
        Assert.assertNotNull(group.getServers());
        Assert.assertEquals(group.getServers().size(), 0);

        List<ServerBean> servers = new ArrayList<ServerBean>();

        group.servers = servers;
        Assert.assertSame(servers, group.getServers());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#setServers(java.util.List)}.
     */
    @Test
    public void testSetServers() {
        List<ServerBean> servers = new ArrayList<ServerBean>();
        group.setServers(servers);

        Assert.assertSame(servers, group.servers);
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#getApplications()}.
     */
    @Test
    public void testGetApplications() {
        Assert.assertNotNull(group.getApplications());
        Assert.assertEquals(group.getApplications().size(), 0);

        List<ApplicationBean> applications = new ArrayList<ApplicationBean>();

        group.applications = applications;
        Assert.assertSame(applications, group.getApplications());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#setApplications(java.util.List)}.
     */
    @Test
    public void testSetApplications() {
        List<ApplicationBean> applications = new ArrayList<ApplicationBean>();
        group.setApplications(applications);

        Assert.assertSame(applications, group.applications);
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#toString()}.
     */
    @Test
    public void testToString() {
        Assert.assertNotNull(group.toString());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.GroupBean#getId()}.
     */
    @Test
    public void testGetId() {
        Assert.assertNull(group.getId());
    }

}
