/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: OperationStateBeanTest.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.entities;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.jasmine.jadort.service.entities.DeploymentBean.DeploymentState;
import org.ow2.jasmine.jadort.service.entities.OperationStateBean.Step;

/**
 * Tests the OperationStateBean class.
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
public class OperationStateBeanTest {

    private OperationStateBean op;

    /**
     * @throws java.lang.Exception
     */
    @BeforeClass
    public static void setUpBeforeClass() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @AfterClass
    public static void tearDownAfterClass() throws Exception {
    }

    /**
     * @throws java.lang.Exception
     */
    @Before
    public void setUp() throws Exception {
        op = new OperationStateBean();
    }

    /**
     * @throws java.lang.Exception
     */
    @After
    public void tearDown() throws Exception {
        op = null;
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#getAimedDeploymentState()}.
     */
    @Test
    public void testGetSetAimedDeploymentState() {
        Assert.assertEquals(DeploymentState.INITIAL, op.getAimedDeploymentState());

        DeploymentState globalDeploymentState = DeploymentState.SET_DEFAULT_OK;
        op.setAimedDeploymentState(globalDeploymentState);
        Assert.assertEquals(globalDeploymentState, op.getAimedDeploymentState());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#getAimedDeploymentProgress()}.
     */
    @Test
    public void testGetSetAimedDeploymentProgress() {
        Assert.assertEquals(Integer.valueOf(0), op.getAimedDeploymentProgress());

        Integer globalDeploymentProgress = Integer.valueOf(33);
        op.setAimedDeploymentProgress(globalDeploymentProgress);
        Assert.assertEquals(globalDeploymentProgress, op.getAimedDeploymentProgress());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#getCurrentStep()}.
     */
    @Test
    public void testGetSetCurrentStep() {
        Assert.assertEquals(Step.SELECT_OPERATION, op.getCurrentStep());

        Step step = Step.EXECUTING_MIGRATION_PART1;
        op.setCurrentStep(step);
        Assert.assertEquals(step, op.getCurrentStep());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#getSelectedGroup()}.
     */
    @Test
    public void testGetSetSelectedGroup() {
        Assert.assertNull(op.getSelectedGroup());

        GroupBean selectedGroup = new GroupBean();
        op.setSelectedGroup(selectedGroup);
        Assert.assertEquals(selectedGroup, op.getSelectedGroup());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#getTopology()}.
     */
    @Test
    public void testGetSetTopology() {
        Assert.assertNull(op.getTopology());

        TopologyBean topology = new TopologyBean();
        op.setTopology(topology);
        Assert.assertEquals(topology, op.getTopology());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#getDeploymentlist()}.
     */
    @Test
    public void testGetSetDeploymentlist() {
        Assert.assertNull(op.getDeploymentlist());

        List<DeploymentBean> deploymentlist = new ArrayList<DeploymentBean>();
        op.setDeploymentlist(deploymentlist);
        Assert.assertEquals(deploymentlist, op.getDeploymentlist());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#getApplication()}.
     */
    @Test
    public void testGetSetApplication() {
        Assert.assertNull(op.getApplication());

        ApplicationBean application = new ApplicationBean();
        op.setApplication(application);
        Assert.assertEquals(application, op.getApplication());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#getDate()}.
     */
    @Test
    public void testGetSetDate() {
        Assert.assertNull(op.getDate());

        Date date = new Date();
        op.setDate(date);
        Assert.assertEquals(date, op.getDate());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#getName()}.
     */
    @Test
    public void testGetSetName() {
        Assert.assertNull(op.getName());

        String name = new String();
        op.setName(name);
        Assert.assertEquals(name, op.getName());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#toString()}.
     */
    @Test
    public void testToString() {
        Assert.assertNotNull(op.toString());
    }

    /**
     * Test method for
     * {@link org.ow2.jasmine.jadort.service.entities.OperationStateBean#getId()}.
     */
    @Test
    public void testGetSetId() {
        Assert.assertNull(op.getId());
    }

}
