/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JadortServiceImplTest.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.service.implementation;

import java.io.File;
import java.util.Hashtable;
import java.util.List;
import java.util.UUID;

import javax.naming.Context;
import javax.naming.InitialContext;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.jasmine.jadort.service.entities.DeploymentBean;
import org.ow2.jasmine.jadort.service.entities.GroupBean;
import org.ow2.jasmine.jadort.service.entities.OperationStateBean;
import org.ow2.jasmine.jadort.service.entities.DeploymentBean.DeploymentState;
import org.ow2.jasmine.jadort.service.entities.OperationStateBean.Step;
import org.ow2.jasmine.jadort.service.IJadortService;

/**
 * Tests the JaDOrT service implementation, needs the JaDOrT service
 * to be deployed on a Java EE server.
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
public class JadortServiceImplTest {

    private static Context context;

    /**
     * @throws java.lang.Exception
     */
    @BeforeClass
    public static void setUpBeforeClass() throws Exception {
        Hashtable<String, Object> env = new Hashtable<String, Object>();
        env.put(Context.INITIAL_CONTEXT_FACTORY, org.ow2.carol.jndi.spi.MultiOrbInitialContextFactory.class.getName());
        JadortServiceImplTest.context = new InitialContext(env);
    }

    /**
     * @throws java.lang.Exception
     */
    @AfterClass
    public static void tearDownAfterClass() throws Exception {
        List<OperationStateBean> ops;
        try {
            IJadortService JaDOrT = (IJadortService) JadortServiceImplTest.context
                    .lookup("JadortConsoleStatefulBean");
            JaDOrT = (IJadortService) JadortServiceImplTest.context.lookup("JadortConsoleStatefulBean");

            ops = JaDOrT.getOperationsList();

            for (OperationStateBean op : ops) {
                JaDOrT.deleteOperation(op);
            }
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
    }

    /**
     * @throws java.lang.Exception
     */
    @Before
    public void setUp() throws Exception {

    }

    /**
     * @throws java.lang.Exception
     */
    @After
    public void tearDown() throws Exception {

    }

    /**
     * Timeout in second to perform the full integration test
     */
    private final int timeoutSecond = 1000;

    /**
     * Non unit test. Unable to perform unit test because of state checker. So
     * this is the only test function that performs full integration test.
     */
    @Test(timeout = timeoutSecond * 100)
    public void testIntegration() {

        try {
            /* Load version 1.0 */
            deployApplication("JaDOrT-console-tests/application1v1/application1.ear");

            /* Load version 2.0 */
            deployApplication("JaDOrT-console-tests/application1v2/application1.ear");

        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
            Assert.fail();
        }
    }

    private void deployApplication(final String applicationPAth) throws Exception, InterruptedException {
        IJadortService JaDOrT = (IJadortService) JadortServiceImplTest.context
                .lookup("JadortConsoleStatefulBean");

        /* --------------------------------------------------------- */
        /* Create an operation */
        String operationName = UUID.randomUUID().toString();
        JaDOrT.createNewOperation(operationName);

        Assert.assertEquals(operationName, JaDOrT.getCurrentOperation().getName());
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* Step increment */
        Assert.assertEquals(JaDOrT.getCurrentOperation().getCurrentStep(), Step.SELECT_OPERATION);
        JaDOrT.next();
        Assert.assertEquals(JaDOrT.getCurrentOperation().getCurrentStep(), Step.INITIALIZE_TOPOLOGY);
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* Test unvalid topology */
        File topo = new File("JaDOrT-console-tests/src/main/resources/XMLSamples/topologyErreur.xml");
        try {
            JaDOrT.loadTopology(new File(topo.toURI()));
            Assert.fail(); // Topology is incorrect, it must not be loaded
        } catch (Exception e) {
            Assert.assertEquals(JaDOrT.getCurrentOperation().getCurrentStep(), Step.INITIALIZE_TOPOLOGY);
        }
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* Test valid topology */
        topo = new File("JaDOrT-console-tests/src/main/resources/XMLSamples/topology.xml");

        try {
            JaDOrT.loadTopology(new File(topo.toURI()));
        } catch (Exception e) {
            e.printStackTrace();
            Assert.fail(); // Topology is correct, it must not enter this
            // catch block
        }
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* Step increment */
        Assert.assertEquals(JaDOrT.getCurrentOperation().getCurrentStep(), Step.INITIALIZE_TOPOLOGY);
        JaDOrT.next();
        Assert.assertEquals(JaDOrT.getCurrentOperation().getCurrentStep(), Step.SELECT_GROUP);
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* Check group */
        Assert.assertEquals(1, JaDOrT.getGroups().size());
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* Select group */
        GroupBean toSelect = JaDOrT.getGroups().get(0);
        JaDOrT.selectGroup(toSelect);
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* Step increment */
        Assert.assertEquals(JaDOrT.getCurrentOperation().getCurrentStep(), Step.SELECT_GROUP);
        JaDOrT.next();
        Assert.assertEquals(JaDOrT.getCurrentOperation().getCurrentStep(), Step.SELECT_APPLICATION);
        Assert.assertEquals(toSelect.getId(), JaDOrT.getSelectedGroup().getId());
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* Select a bad application */
        try {
            JaDOrT.createApplication(new File("JaDOrT-console-tests/noApplication.war").toURL());
            Assert.fail();
        } catch (Exception e) {
            // all right
        }
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* Select a good application */
        try {
            JaDOrT.createApplication(new File(applicationPAth).toURL());
        } catch (Exception e) {
            Assert.fail();
        }
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* Step increment */
        Assert.assertEquals(JaDOrT.getCurrentOperation().getCurrentStep(), Step.SELECT_APPLICATION);
        JaDOrT.next();
        Assert.assertEquals(JaDOrT.getCurrentOperation().getCurrentStep(), Step.EXECUTING_MIGRATION_PART1);
        // Assert.assertNotNull(JaDOrT.getDeployments().get(0).getNewApplication());
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* UPLOAD */
        boolean pasFini = true;
        JaDOrT.next();
        while (pasFini) {
            Thread.sleep(3000);
            pasFini = false;
            for (DeploymentBean dep : JaDOrT.getDeployments()) {
                if (dep.getDeploymentState().equals(DeploymentState.UPLOAD_OK)) {
                    pasFini = pasFini || false;
                } else {
                    pasFini = pasFini || true;
                }
            }
        }
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* DEPLOY */
        JaDOrT.next();
        pasFini = true;
        while (pasFini) {
            Thread.sleep(3000);
            pasFini = false;
            for (DeploymentBean dep : JaDOrT.getDeployments()) {
                if (dep.getDeploymentState().equals(DeploymentState.DEPLOY_OK)) {
                    pasFini = pasFini || false;
                } else {
                    pasFini = pasFini || true;
                }
            }
        }
        /* --------------------------------------------------------- */

        /* --------------------------------------------------------- */
        /* SET DEFAULT */
        JaDOrT.next();
        pasFini = true;
        while (pasFini) {
            Thread.sleep(3000);
            pasFini = false;
            for (DeploymentBean dep : JaDOrT.getDeployments()) {
                if (dep.getDeploymentState().equals(DeploymentState.SET_DEFAULT_OK)) {
                    pasFini = pasFini || false;
                } else {
                    pasFini = pasFini || true;
                }
            }
        }
        /* --------------------------------------------------------- */

        if (JaDOrT.getCurrentOperation().getDeploymentlist().get(0).getOldApplication() != null) {

            /* --------------------------------------------------------- */
            /* Passage a l'ecran suivant */
            JaDOrT.next();
            while (!JaDOrT.getCurrentOperation().getCurrentStep().equals(Step.EXECUTING_MIGRATION_PART2)) {
                Thread.sleep(3000);
            }
            /* --------------------------------------------------------- */

            /* --------------------------------------------------------- */
            /* UNDEPLOY OLD */
            JaDOrT.next();
            pasFini = true;
            while (pasFini) {
                Thread.sleep(3000);
                pasFini = false;
                for (DeploymentBean dep : JaDOrT.getDeployments()) {
                    if (dep.getDeploymentState().equals(DeploymentState.UNDEPLOY_OK)) {
                        pasFini = pasFini || false;
                    } else {
                        pasFini = pasFini || true;
                    }
                }
            }
            /* --------------------------------------------------------- */

            /* --------------------------------------------------------- */
            /* ERASE OLD */
            JaDOrT.next();
            pasFini = true;
            while (pasFini) {
                Thread.sleep(3000);
                pasFini = false;
                for (DeploymentBean dep : JaDOrT.getDeployments()) {
                    if (dep.getDeploymentState().equals(DeploymentState.ERASE_OK)) {
                        pasFini = pasFini || false;
                    } else {
                        pasFini = pasFini || true;
                    }
                }
            }
            /* --------------------------------------------------------- */
        }
    }

}
