/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ServerActionTest.java 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.tests;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStreamReader;

import org.ow2.jasmine.jadort.service.action.JonasServerAction;
import org.ow2.jasmine.jadort.service.action.ServerAction;
import org.ow2.jasmine.jadort.service.entities.ApplicationBean;
import org.ow2.jasmine.jadort.service.entities.JMXConnectorBean;
import org.ow2.jasmine.jadort.service.entities.ServerBean;

/**
 * This is a dummy test class for the JOnAS Server Action class.
 *
 * @author Malek Chahine
 * @author Remy Bresson
 * @author S. Ali Tokmen
 */
public class ServerActionTest {

    protected static final String DEFAULT_FILE = "D:\\Documents and Settings\\tokmensa\\Bureau\\TEMP\\1.0.0\\test.war";

    public static void main(final String[] args) throws Exception {
        System.out.println("Enter file name [" + ServerActionTest.DEFAULT_FILE + "]");
        String file = new BufferedReader(new InputStreamReader(System.in)).readLine();
        if (file.length() < 1) {
            file = ServerActionTest.DEFAULT_FILE;
        }

        JMXConnectorBean jmx = new JMXConnectorBean();
        jmx.setConnectorUrl("service:jmx:rmi:///jndi/rmi://localhost:1099/jrmpconnector_jonas");
        ServerBean server = new ServerBean();
        server.setConnector(jmx);
        server.setName("test");

        ServerAction.setActionType(JonasServerAction.class);
        ServerAction serverAction = ServerAction.getServerAction(server);

        try {
            System.out.println("Trying serverAction.listOfApplications :");
            for (ApplicationBean application : serverAction.listOfApplications()) {
                System.out.println("\t" + application.toString());
            }

            System.out.println("Trying serverAction.upload :");
            String newApplication = serverAction.upload(new ApplicationBean(new File(file)));
            System.out.println("\t" + newApplication);

            System.out.println("Trying serverAction.deploy(\"" + newApplication + "\")");
            serverAction.deploy(newApplication);
            System.out.println("\tOK");

            System.out.println("Trying serverAction.setDefault(\"" + newApplication + "\")");
            String oldApplication = serverAction.setDefault(newApplication);
            System.out.println("\t" + oldApplication);

            System.out.println("Trying serverAction.undeploy(\"" + oldApplication + "\")");
            serverAction.undeploy(oldApplication);
            System.out.println("\tOK");

            System.out.println("Trying serverAction.erase(\"" + oldApplication + "\")");
            serverAction.erase(oldApplication);
            System.out.println("\tOK");
        } finally {
            System.out.println("Tests finished. Here comes the log:");
            System.out.println(serverAction.flushLog());
        }
    }

}
