/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GetDeploymentsCommand.as 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.jadort.client.flex.command {
    
    import com.adobe.cairngorm.commands.*;
    import com.adobe.cairngorm.control.*;
    import flash.utils.clearTimeout;
    import mx.collections.ArrayCollection;
    import mx.controls.Alert;
    import mx.rpc.IResponder;
    import mx.rpc.events.FaultEvent;
    import mx.rpc.events.ResultEvent;
    import org.ow2.jasmine.jadort.client.flex.business.*;
    import org.ow2.jasmine.jadort.client.flex.event.*;
    import org.ow2.jasmine.jadort.client.flex.model.*;
    import org.ow2.jasmine.jadort.client.flex.vo.*;


    public class GetDeploymentsCommand extends SequenceCommandWithErrorHandling implements IResponder {

        private var my_timedProcess:uint ;

        override public function execute( event : CairngormEvent ): void {
            
            // delegate to the GetDeploymentsDelegate to call the getDeployments service
            var delegate : GetDeploymentsDelegate  = JadortModelLocator.getInstance(). getDeploymentDelegete();
            delegate.responder = this;
            delegate.getDeployments();
        }

        /**
         * Manage the result found by a delegate.
         */
        public function result( event : Object ) : void {
            
            // Execute canGoToNextStep and canGoToPreviousStep before updating UI
            var canGoToNextStepEvent : CanGoToNextStepEvent = new CanGoToNextStepEvent();
            CairngormEventDispatcher.getInstance().dispatchEvent(canGoToNextStepEvent);

            var canGoToPreviousStepEvent : CanGoToPreviousStepEvent = new CanGoToPreviousStepEvent();
            CairngormEventDispatcher.getInstance().dispatchEvent(canGoToPreviousStepEvent);

            
            var resultEvent : ResultEvent = event as ResultEvent;
            var arrayCollection : ArrayCollection = resultEvent.result as ArrayCollection;
            // stop the timer 
            flash.utils.clearTimeout(my_timedProcess);
            var model :JadortModelLocator = JadortModelLocator.getInstance();
            var DeployAverage : Number = 0;
            
            // set attributes in the model to upadte the UI
            model.deployments = arrayCollection;
            
            // global state of the deploymens 
            var isErrorState : Boolean = false;
            // global state of the deployments 
            var allServerisNotRunning : Boolean = true;
            
            // fetch the deplyments list to get the global state of deployments
            for(var i:Number = 0 ;i<model.deployments.length;i++) {
                if  (model.deployments.getItemAt(i).state== "Running") {
                    allServerisNotRunning = false;
                }
                if  (isErrorState ||model.deployments.getItemAt(i).state== "Error !") {
                    isErrorState = true;
                }
                // calculate the Deployment Average of all deplyments
                DeployAverage = DeployAverage + model.deployments.getItemAt(i).progress;
            }
            
            // dispatch ProgressEvent to update UI (update the global peogress bar in th execution migration steps)
            // (DeployAverage /  model.deployments.length) for the progress and isErrorState for the color of progre
            // red if isErrorState = true
            CairngormEventDispatcher.getInstance().dispatchEvent(new ProgressEvent("progress",(DeployAverage /  model.deployments.length),isErrorState));
            
            // every 2 seconds we call the refreshgetDepoyment function to update the UI
            my_timedProcess= flash.utils.setTimeout(refreshgetDepoyment,2000,allServerisNotRunning);
        }

        public function refreshgetDepoyment(allServerisNotRunning : Boolean): void {
            var model :JadortModelLocator = JadortModelLocator.getInstance();
            // if all server is not running, so we need to recall the dispatch GetDeploymentsEvent to update the UI
            // else we only stop the timer
            if((!allServerisNotRunning) ) {
                flash.utils.clearTimeout(my_timedProcess);
                nextEvent = new GetDeploymentsEvent();
                executeNextCommand();
            } else {
                flash.utils.clearTimeout(my_timedProcess);
            }
        }
    }
    
}