/**
 * JaDOrT: JASMINe Deployment Orchestration Tool
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 France Telecom R&D
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JadortModelLocator.as 1503 2008-06-23 13:36:10Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.jadort.client.flex.model {
    
    import com.adobe.cairngorm.model.IModelLocator;
    import mx.collections.ArrayCollection;
    import org.ow2.jasmine.jadort.client.flex.business.*;
    import org.ow2.jasmine.jadort.client.flex.vo.*;
  
    /**
     * this class is the model locator of the application, we use it to store the client side model.
     * (it is implement the model in the Cairngorm Model-View-Controller architecture)
     */
    [Bindable]	
    public class JadortModelLocator implements IModelLocator  {
        
        public var index : Number = 0;
        public var uploaded : Number = 0;
       	public var deployed : Number = 0;
       	public var ExecutionMigrationState : Number = 0;
        public var nextButtonEnabled : Boolean = false;
        public var previousButtonEnabled : Boolean = false;
        public var selectedGroup : GroupVO = null;
        public var uploadedApplication : ApplicationVO = null;
        public var refreshScreen : Boolean = false;
        public var selectedOperation : OperationStateVO = null;
		
        [ArrayElementType(OperationStateVO)]
        public var operationsList : ArrayCollection;
		
        [ArrayElementType(ServerVO)]
        public var servers : ArrayCollection;
        
        [ArrayElementType(GroupVO)]
        public var groups : ArrayCollection;
        
	  	[ArrayElementType(ServerVO)]
    	public var selectedServers : ArrayCollection;
    	      
	  	[ArrayElementType(DeploymentVO)]
	  	public var deployments : ArrayCollection;
        
        private var serversDelegate : ServersDelegate;
        
        private var groupsDelegate : GetGroupsDelegate;
        
        private var selectedGroupDelegate : GetSelectedGroupDelegate;
        
        private var getDeploymentsDelegete : GetDeploymentsDelegate;
        
        private var abortServerDelegate : AbortServerDelegate;
        
        private var restartServerDelegate : RestartServerDelegate;
        
        private var ignoreServerDelegate : IgnoreServerDelegate;
               
       	private var createApplicationDelegate : CreateApplicationDelegate;
	  	
	  	private var checkServerDelegate : CheckServerDelegate;
        
        private static var modelLocator : JadortModelLocator;
            
        private var pageIndexDelegate : GetPageIndexDelegate;
        
        private var nextDelegate : NextDelegate;
        
        private var previousDelegate : PreviousDelegate;                
        
        private var canGoToNextStepDelegate :CanGoToNextStepDelegate;
        
        private var canGoToPreviousStepDelegate :CanGoToPreviousStepDelegate;
        
        private var loadTopologyDelegate :LoadTopologyDelegate;
        
       	private var selectGroupDelegate :SelectGroupDelegate;
        
        private var selectOperationDelegate : SelectOperationDelegate;
       
        private var createNewOperationDelegate : CreateNewOperationDelegate;
        
        private var operationsListDelegate : GetOperationsListDelegate;
        
        private var deleteOperationDelegate : DeleteOperationDelegate;
        
        private var initializeDelegate : InitializeDelegate;
        
        public static function getInstance() : JadortModelLocator  {
            if ( modelLocator == null ) {
				modelLocator = new JadortModelLocator();
            }
            return modelLocator;
	   }
	   
       public function JadortModelLocator() {
           super();
           if ( JadortModelLocator.modelLocator != null )
					throw new Error( "Only one ModelLocator instance should be instantiated" );	
           this.selectedServers = new ArrayCollection();
           this.deployments = new ArrayCollection();
           this.getDeploymentsDelegete = new GetDeploymentsDelegate();
           this.abortServerDelegate = new AbortServerDelegate();
           this.restartServerDelegate = new RestartServerDelegate();
           this.ignoreServerDelegate = new IgnoreServerDelegate();
           this.groupsDelegate = new GetGroupsDelegate();
           this.createApplicationDelegate = new CreateApplicationDelegate();
           this.uploadedApplication =new ApplicationVO();
           this.checkServerDelegate = new CheckServerDelegate();
           this.pageIndexDelegate = new GetPageIndexDelegate();
           this.nextDelegate = new NextDelegate();
           this.canGoToNextStepDelegate= new CanGoToNextStepDelegate();
           this.previousDelegate= new PreviousDelegate();
           this.loadTopologyDelegate = new LoadTopologyDelegate();
           this.selectGroupDelegate = new SelectGroupDelegate();
           this.canGoToPreviousStepDelegate = new CanGoToPreviousStepDelegate();
           this.selectedGroupDelegate= new GetSelectedGroupDelegate();
           this.selectOperationDelegate= new SelectOperationDelegate();
           this.createNewOperationDelegate = new CreateNewOperationDelegate();
           this.operationsListDelegate= new GetOperationsListDelegate();
           this.deleteOperationDelegate = new DeleteOperationDelegate();
           this.initializeDelegate = new InitializeDelegate();
       }
       
       public function getGroupsDelegate() : GetGroupsDelegate {
           return groupsDelegate;
       }
       
       public function getSelectedGroupDelegate() : GetSelectedGroupDelegate {
           return selectedGroupDelegate;
       }
       
       public function getCanGoToNextStepDelegate() : CanGoToNextStepDelegate {
           return canGoToNextStepDelegate;
       }
       
       public function getCanGoToPreviousStepDelegate() : CanGoToPreviousStepDelegate {
           return canGoToPreviousStepDelegate;
       }
       
       public function getPageIndexDelegate() : GetPageIndexDelegate {
           return pageIndexDelegate;
       }
       
       public function getNextDelegate() : NextDelegate {
           return nextDelegate;
       }
       
       public function getPreviousDelegate() : PreviousDelegate {
           return previousDelegate;
       }
       
       public function getDeploymentDelegete() : GetDeploymentsDelegate {
           return getDeploymentsDelegete;
       }
       
       public function getAbortServerDelegate() : AbortServerDelegate {
           return abortServerDelegate;
       }
       
       public function getRestartServerDelegate() : RestartServerDelegate {
           return restartServerDelegate;
       }
       
       public function getIgnoreServerDelegate() : IgnoreServerDelegate {
           return ignoreServerDelegate;
       }
       
       public function getCheckServerDelegate() : CheckServerDelegate {
           return checkServerDelegate;
       }
       
       public function getLoadTopologyDelegate() : LoadTopologyDelegate {
           return loadTopologyDelegate;
       }
       
       public function getSelectGroupDelegate() : SelectGroupDelegate {
           return selectGroupDelegate;
       }
       
       public function addServer(s : ServerVO ) : void {
           this.selectedServers.addItem(s);
       }
       
       public function getServers() : ArrayCollection {
           return this.servers;
           }
       
       public function getServerByIndex(index :Number) : ServerVO {
           var  server : ServerVO = this.getServers().getItemAt(index) as ServerVO;
	       return server; 	
	   }
       
       public function getCreateApplicationDelegate() : CreateApplicationDelegate {
           return createApplicationDelegate;
       }
       
       public function getUploadedApplication() : ApplicationVO {
           return uploadedApplication;
       }
       
       public function setUploadedApplication(application : ApplicationVO) : void {
           this.uploadedApplication = application;
       }
       
       public function getSelectedGroup() : GroupVO {
           return selectedGroup;
       }
       
       public function setSelectedGroup(selectedGroup : GroupVO) : void {
           this.selectedGroup = selectedGroup;
       }
       
       public function getRefreshScreen() : Boolean {
           return refreshScreen;
       }
       
       public function setRefreshScreen(refreshScreen : Boolean) : void {
           this.refreshScreen = refreshScreen;
       }
       
       public function getSelectOperationDelegate() : SelectOperationDelegate {
           return selectOperationDelegate;
       }
       
       public function getCreateNewOperationDelegate() : CreateNewOperationDelegate {
           return createNewOperationDelegate;
	   }
       
       public function getOperationsListDelegate() : GetOperationsListDelegate {
           return operationsListDelegate;
	   }
       
       public function getDeleteOperationDelegate() : DeleteOperationDelegate {
           return deleteOperationDelegate;
       }
       
       public function getInitializeDelegate() : InitializeDelegate {
           return this.initializeDelegate ;
       }
       
       public function setIndex(index : Number) : void {
           this.index = index;
       }
       
       public function getIndex() : Number {
           return this.index ;
       }
       
       public function getSelectedOperation() : OperationStateVO {
           return this.selectedOperation ;
       }
    }
}